@@ -130,7 +130,7 @@ groupwise_auth_loop (CamelService *service,
 				"GroupWise", url->user, url->host);
 			url->passwd =
 				camel_session_get_password (
-					session, service, "Groupwise", prompt,
+					session, service, prompt,
 					"password", prompt_flags, error);
 			g_free (prompt);
 
